#
# spec file for package khelpcenter
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define kf6_version 6.6.0
%define qt6_version 6.6.0

%bcond_without released
Name:           khelpcenter
Version:        25.04.0
Release:        1.1
Summary:        KDE Documentation Application
License:        GPL-2.0-or-later
URL:            https://apps.kde.org/khelpcenter
Source0:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz.sig
Source2:        applications.keyring
%endif
BuildRequires:  kf6-extra-cmake-modules >= %{kf6_version}
BuildRequires:  libxapian-devel
BuildRequires:  pkgconfig
BuildRequires:  cmake(KF6Archive) >= %{kf6_version}
BuildRequires:  cmake(KF6Bookmarks) >= %{kf6_version}
BuildRequires:  cmake(KF6Completion) >= %{kf6_version}
BuildRequires:  cmake(KF6Config) >= %{kf6_version}
BuildRequires:  cmake(KF6CoreAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6DBusAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6DocTools) >= %{kf6_version}
BuildRequires:  cmake(KF6I18n) >= %{kf6_version}
BuildRequires:  cmake(KF6KIO) >= %{kf6_version}
BuildRequires:  cmake(KF6Service) >= %{kf6_version}
BuildRequires:  cmake(KF6TextTemplate)
BuildRequires:  cmake(KF6WindowSystem) >= %{kf6_version}
BuildRequires:  cmake(KF6XmlGui) >= %{kf6_version}
BuildRequires:  cmake(Qt6DBus) >= %{qt6_version}
BuildRequires:  cmake(Qt6PrintSupport) >= %{qt6_version}
BuildRequires:  cmake(Qt6WebEngineWidgets) >= %{qt6_version}
BuildRequires:  cmake(Qt6Widgets) >= %{qt6_version}
BuildRequires:  cmake(Qt6Xml) >= %{qt6_version}
BuildRequires:  pkgconfig(libxml-2.0)
# It can only build on the same platforms as Qt Webengine
ExclusiveArch:  x86_64 %{x86_64} aarch64 riscv64
# khelpcenter uses some images and stylesheets from kdoctools (boo#1011094)
Requires:       kf6-kdoctools >= %{kf6_version}
Conflicts:      kdebase4-runtime < 17.04.1
Provides:       suse_help_viewer
Provides:       khelpcenter5 = %{version}
Obsoletes:      khelpcenter5 < %{version}
Obsoletes:      khelpcenter5-lang < %{version}

%description
Application to show KDE Applications' documentation.

%lang_package

%prep
%autosetup -p1

sed -i 's,^#!/bin/env python3$,#!/usr/bin/python3,' searchhandlers/khc_mansearch.py

%build
%cmake_kf6

%kf6_build

%install
%kf6_install

%find_lang %{name} --with-html --all-name

%ldconfig_scriptlets

%files
%license LICENSES/*
%doc README*
%doc %lang(en) %{_kf6_htmldir}/en/*/
%{_kf6_applicationsdir}/org.kde.khelpcenter.desktop
%{_kf6_appstreamdir}/org.kde.khelpcenter.metainfo.xml
%{_kf6_bindir}/khelpcenter
%{_kf6_configkcfgdir}/khelpcenter.kcfg
%{_kf6_debugdir}/khelpcenter.categories
%{_kf6_sharedir}/dbus-1/services/org.kde.khelpcenter.service
%{_kf6_sharedir}/khelpcenter/
%{_libexecdir}/khc_mansearch.py
%{_libexecdir}/khc_xapianindexer
%{_libexecdir}/khc_xapiansearch

%files lang -f %{name}.lang
%exclude %{_kf6_htmldir}/en/*/

%changelog
* Mon Apr 14 2025 Christophe Marin <christophe@krop.fr>
- Update to 25.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/25.04.0/
- No code change since 25.03.90
* Sat Mar 29 2025 Christophe Marin <christophe@krop.fr>
- Update to 25.03.90
  * New feature release
- Changes since 24.12.3:
  * The operating system name is "macOS"
* Tue Mar  4 2025 Christophe Marin <christophe@krop.fr>
- Update to 24.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.3/
- No code change since 24.12.2
* Tue Feb  4 2025 Christophe Marin <christophe@krop.fr>
- Update to 24.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.2/
- No code change since 24.12.1
* Tue Jan  7 2025 Christophe Marin <christophe@krop.fr>
- Update to 24.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.1/
- No code change since 24.12.0
* Sun Dec  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.0/
- No code change since 24.11.90
* Mon Dec  2 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.11.90
  * New feature release
- No code change since 24.11.80
* Sat Nov 16 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.11.80
  * New feature release
- Changes since 24.08.3:
  * Don't include quiet packages in feature_summary
  * Fix CMake include
  * Add clang-format git commit hook
  * Add git blame ignore file
  * Run clang-format
  * Categorize the app as "Documentation" and add "Center" to name
  * Fix cmakelint issues
  * searchhandlers: Replace Perl manpage script with Python (kde#493223)
  * Put more relevant man search results first
  * Fix links for Windows and Mac tips (spotted by smart.luck6184)
* Tue Nov  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.3/
- No code change since 24.08.2
* Tue Oct  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.2/
- No code change since 24.08.1
* Tue Sep 10 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.1/
- No code change since 24.08.0
* Mon Aug 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.0/
- Changes since 24.05.2:
  * CMake: Require Qt6::PrintSupport
* Tue Jul  2 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.2/
- No code change since 24.05.1
* Wed Jun 12 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.1/
- No code change since 24.05.0
* Sun May 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.0/
- No code change since 24.04.80
* Fri May  3 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.04.80
  * New feature release
- Changes since 24.02.2:
  * Readd page search feature (kde#483972)
  * Load documentation pages with KIO::HideProgressInfo
  * Fix missing URL redirection implementation in web engine feeding from KIO
  * Trigger Quirks mode for index/glossary/search HTML pages
  * Unbreak endless invocation loop with "info" pages (kde#484977)
  * page templates: fix CSS loading, DOCTYPE wrong uppercase HTML, not html
  * Glossary pages: fix broken styling
  * Fix outdated use of kdoctools5-common resources, kdoctools6-common now
  * Contents & Glossary list: always activate entry on single click
  * Forward/backward navigation: KToolBarPopupAction needs use of popupMenu()
  * Use ECMDeprecationSettings
  * appstream: use desktop-application type, add developer tag
  * Bump min required KF6 to 6.0 (and align Qt min version)
* Tue Apr  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.02.2/
- Changes since 24.02.1:
  * Load documentation pages with KIO::HideProgressInfo
  * Fix missing URL redirection implementation in web engine feeding from KIO
  * Revert "Fix opening subpages of documentation"
  * Fix opening subpages of documentation (kde#484176)
  * Trigger Quirks mode for index/glossary/search HTML pages
  * Unbreak endless invocation loop with "info" pages (kde#484977)
  * Glossary pages: fix broken styling
  * Fix outdated use of kdoctools5-common resources, kdoctools6-common now
  * Contents & Glossary list: always activate entry on single click
* Tue Mar 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.02.1/
- No code change since 24.02.0
* Fri Feb 23 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.0
  * New feature release
- No code change since 24.01.95
* Wed Sep 20 2023 Christophe Marin <christophe@krop.fr>
- Init khelpcenter
